==> org.eclipse.escet.cif.parser.source_0.5.0.v20220329-130407.jar: org/eclipse/escet/cif/parser/ast/functions/AElifFuncStatement.java <==
//////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2010, 2022 Contributors to the Eclipse Foundation
//
// See the NOTICE file(s) distributed with this work for additional
// information regarding copyright ownership.
//
// This program and the accompanying materials are made available
// under the terms of the MIT License which is available at
// https://opensource.org/licenses/MIT
//
// SPDX-License-Identifier: MIT
//////////////////////////////////////////////////////////////////////////////

package org.eclipse.escet.cif.parser.ast.functions;

import java.util.List;

import org.eclipse.escet.cif.parser.ast.ACifObject;
import org.eclipse.escet.cif.parser.ast.expressions.AExpression;
import org.eclipse.escet.common.position.metamodel.position.Position;

/** An 'elif' part of an 'if' internal function statement. */
public class AElifFuncStatement extends ACifObject {
    /** The guards of the elif. */
    public final List<AExpression> guards;

    /** The 'then' statements of the 'elif'. */
    public final List<AFuncStatement> thens;

    /**
     * Constructor for the {@link AElifFuncStatement} class.
     *
     * @param guards The guards of the 'elif'.
     * @param thens The 'then' statements of the 'elif'.
     * @param position Position information.
     */
    public AElifFuncStatement(List<AExpression> guards, List<AFuncStatement> thens, Position position) {
        super(position);
        this.guards = guards;
        this.thens = thens;
    }
}

==> org.eclipse.escet.cif.parser.source_0.7.0.v20220930-130348.jar: org/eclipse/escet/cif/parser/ast/functions/AElifFuncStatement.java <==
//////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2010, 2022 Contributors to the Eclipse Foundation
//
// See the NOTICE file(s) distributed with this work for additional
// information regarding copyright ownership.
//
// This program and the accompanying materials are made available
// under the terms of the MIT License which is available at
// https://opensource.org/licenses/MIT
//
// SPDX-License-Identifier: MIT
//////////////////////////////////////////////////////////////////////////////

package org.eclipse.escet.cif.parser.ast.functions;

import java.util.List;

import org.eclipse.escet.cif.parser.ast.ACifObject;
import org.eclipse.escet.cif.parser.ast.expressions.AExpression;
import org.eclipse.escet.common.java.TextPosition;

/** An 'elif' part of an 'if' internal function statement. */
public class AElifFuncStatement extends ACifObject {
    /** The guards of the elif. */
    public final List<AExpression> guards;

    /** The 'then' statements of the 'elif'. */
    public final List<AFuncStatement> thens;

    /**
     * Constructor for the {@link AElifFuncStatement} class.
     *
     * @param guards The guards of the 'elif'.
     * @param thens The 'then' statements of the 'elif'.
     * @param position Position information.
     */
    public AElifFuncStatement(List<AExpression> guards, List<AFuncStatement> thens, TextPosition position) {
        super(position);
        this.guards = guards;
        this.thens = thens;
    }
}
